@@ -25,7 +25,7 @@
 # from your version.
 
 """
-    General functions and classes shared in the codebase
+General functions and classes shared in the codebase
 """
 
 from collections import deque
@@ -389,9 +389,9 @@ def open_file_directory(path_or_uri: str) -> None:
         ILFree(pidl)
         CoUninitialize()
     elif platform == 'darwin':
-        subprocess.Popen(["open", f.get_parent().get_parse_name()])
+        subprocess.Popen(["open", (f.get_parent() or f).get_parse_name()])
     else:
-        subprocess.Popen(["xdg-open", f.get_parent().get_parse_name()])
+        subprocess.Popen(["xdg-open", (f.get_parent() or f).get_parse_name()])
 
 
 def open_shelf(path):
