@@ -278,16 +278,15 @@ class Marker(GObject.GObject):
         try:
             return self.__values[gproperty.name]
         except KeyError:
-            raise AttributeError('unknown property %s' % property.name)
+            raise AttributeError('unknown property %s' % gproperty.name)
 
     def do_set_property(self, gproperty, value):
         """
         Sets a GObject property
         """
-        try:
-            self.__values[gproperty.name] = value
-        except KeyError:
-            raise AttributeError('unknown property %s' % property.name)
+        if gproperty.name not in self.__values:
+            raise AttributeError('unknown property %s' % gproperty.name)
+        self.__values[gproperty.name] = value
 
 
 class MarkerManager(providers.ProviderHandler):
